@@ -1,6 +1,6 @@
 package Rinci;
 
-our $VERSION = '1.1.40'; # VERSION
+our $VERSION = '1.1.41'; # VERSION
 
 1;
 # ABSTRACT: Language-neutral metadata for your code
@@ -15,6 +15,17 @@ __END__
 
 Rinci - Language-neutral metadata for your code
 
+=head1 VERSION
+
+version 1.1.41
+
+=head1 DESCRIPTION
+
+=head1 FUNCTIONS
+
+
+None are exported by default, but they are exportable.
+
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Rinci>.
@@ -26,7 +37,7 @@ Source repository is at L<https://github.com/sharyanto/perl-Rinci>.
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website
-http://rt.cpan.org/Public/Dist/Display.html?Name=Rinci
+L<https://rt.cpan.org/Public/Dist/Display.html?Name=Rinci>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
